@@ -22,7 +22,7 @@ from .reference_kmer_index import ReferenceKmerIndex
 from pathos.multiprocessing import Pool
 from obgraph.variants import VcfVariants
 from .unique_variant_kmers import UniqueVariantKmersFinder
-from shared_memory_wrapper.shared_memory import to_shared_memory, from_shared_memory, remove_shared_memory_in_session, to_file, from_file, object_to_shared_memory, object_from_shared_memory
+from shared_memory_wrapper import to_shared_memory, from_shared_memory, remove_shared_memory_in_session, to_file, from_file, object_to_shared_memory, object_from_shared_memory
 from shared_memory_wrapper import get_shared_pool, close_shared_pool
 from obgraph.variant_to_nodes import VariantToNodes, NodeToVariants
 from obgraph.haplotype_matrix import HaplotypeMatrix
@@ -51,19 +51,19 @@ def create_index_single_thread(args, interval=None):
     logging.info("Loading data")
     #graph = Graph.from_file(args.graph_file_name)
     if args.graph_file_name is not None:
-        graph = from_shared_memory(Graph, "graph_shared"+args.shared_memory_unique_id)
+        graph = object_from_shared_memory("graph_shared"+args.shared_memory_unique_id)
         reference = None
     else:
         graph = None
         assert args.reference_fasta is not None
         assert args.reference_name is not None, "Reference name must be specified"
-        logging.info("Reference name is *%s*" % args.reference_name)
         try:
             fasta = Fasta(args.reference_fasta)
-            logging.info("Names in fasta: %s" % str(fasta.keys()))
             reference = fasta[args.reference_name]
             assert len(reference) > 0, "Length of ref sequennce is 0. Seomthing is wrong"
         except KeyError:
+            logging.info("Reference name is *%s*" % args.reference_name)
+            logging.info("Names in fasta: %s" % str(fasta.keys()))
             logging.error("Did not find reference name %s in %s" % (args.reference_name, args.reference_fasta))
             raise
 
@@ -107,8 +107,11 @@ def create_index(args):
     r = args.shared_memory_unique_id
 
     if args.graph_file_name is not None:
+        logging.info("Reading obgraph")
         graph = Graph.from_file(args.graph_file_name)
-        to_shared_memory(graph, "graph_shared"+r)
+        logging.info("Putting obgraph in shared memory")
+        object_to_shared_memory(graph, "graph_shared"+r)
+        logging.info("Done putting in shared memory")
 
     if args.threads == 1:
         kmers = create_index_single_thread(args)
@@ -293,7 +296,8 @@ def run_argument_parser(args):
     subparser.add_argument("-O", "--only-store-kmers", required=False, default=False, type=bool, help="Can be used when making from fasta file, will then not store the index since an index is not needed")
     subparser.set_defaults(func=make_reference_kmer_index)
 
-    def make_unique_variant_kmers_single_thread(variants, args):
+    def make_unique_variant_kmers_single_thread(data):
+        variants, args = data
         args = object_from_shared_memory(args)
         #variant_to_nodes = from_shared_memory(VariantToNodes, "variant_to_nodes_shared"+r)
         variant_to_nodes = args["variant_to_nodes"]
@@ -334,18 +338,23 @@ def run_argument_parser(args):
         return flat_kmers
 
     def make_unique_variant_kmers(args):
+        from shared_memory_wrapper.util import chunked_imap
         args = vars(args)
         args_orig = args
         args.pop("func")  # necessary for putting args in shared memory
 
+        n_threads = args["n_threads"]
+
         logging.info("Reading all variants")
-        variants = VcfVariants.from_vcf(args["vcf"], skip_index=True, make_generator=True)
+        pool = get_shared_pool(n_threads) #Pool(args["n_threads"])
+        variants = VcfVariants.from_vcf(args["vcf"], skip_index=True, make_generator=True, dont_encode_chromosomes=True)
         variants = variants.get_chunks(chunk_size=args["chunk_size"])
-        pool = Pool(args["n_threads"])
 
         all_flat_kmers = []
         args = object_to_shared_memory(args)
-        for flat_kmers in pool.starmap(make_unique_variant_kmers_single_thread, zip(variants, repeat(args))):
+        logging.info("Starting parallel")
+        #for flat_kmers in pool.imap(make_unique_variant_kmers_single_thread, zip(variants, repeat(args))):
+        for flat_kmers in chunked_imap(pool, make_unique_variant_kmers_single_thread, zip(variants, repeat(args)), chunk_size=n_threads*4):
             all_flat_kmers.append(flat_kmers)
 
         logging.info("Merge all flat kmers")
@@ -491,7 +500,7 @@ def run_argument_parser(args):
 
         if args.critical_graph_paths is None:
             logging.info("Making critical graph paths since not specified")
-            args.critical_paths = CriticalGraphPaths.from_graph(graph, args.k)
+            args.critical_paths = CriticalGraphPaths.from_graph(args.graph, args.kmer_size)
 
         args.position_id = PositionId.from_graph(args.graph) if args.position_id is not None else None
 
@@ -591,7 +600,7 @@ def run_argument_parser(args):
     subparser = subparsers.add_parser("count_kmers")
     subparser.add_argument("-f", "--flat-kmers", required=True, type=FlatKmers.from_file)
     subparser.add_argument("-o", "--out-file-name", required=True)
-    subparser.add_argument("-m", "--modulo", required=False, type=int, default=200000033)
+    subparser.add_argument("-m", "--modulo", required=False, type=int, default=0)
     subparser.add_argument("-s", "--subsample-ratio", required=False, type=int, default=1, help="1 to keep every kmer, 2 for every other etc")
     subparser.set_defaults(func=count_kmers)
 
